@@ -1,20 +1,5 @@
-/*
- * This file is part of Tepl, a text editor library.
- *
- * Copyright 2016-2020 - Sébastien Wilmet <swilmet@gnome.org>
- *
- * Tepl is free software; you can redistribute it and/or modify it under
- * the terms of the GNU Lesser General Public License as published by the
- * Free Software Foundation; either version 2.1 of the License, or (at your
- * option) any later version.
- *
- * Tepl is distributed in the hope that it will be useful, but WITHOUT ANY
- * WARRANTY; without even the implied warranty of MERCHANTABILITY or
- * FITNESS FOR A PARTICULAR PURPOSE.  See the GNU Lesser General Public
- * License for more details.
- *
- * You should have received a copy of the GNU Lesser General Public License
- * along with this library; if not, see <http://www.gnu.org/licenses/>.
+/* SPDX-FileCopyrightText: 2016-2020 - Sébastien Wilmet <swilmet@gnome.org>
+ * SPDX-License-Identifier: LGPL-3.0-or-later
  */
 
 #ifndef TEPL_BUFFER_H
@@ -31,6 +16,7 @@
 G_BEGIN_DECLS
 
 #define TEPL_TYPE_BUFFER (tepl_buffer_get_type ())
+_TEPL_EXTERN
 G_DECLARE_DERIVABLE_TYPE (TeplBuffer, tepl_buffer,
 			  TEPL, BUFFER,
 			  GtkSourceBuffer)
@@ -61,29 +47,47 @@ typedef enum _TeplSelectionType
 	TEPL_SELECTION_TYPE_MULTIPLE_LINES
 } TeplSelectionType;
 
+_TEPL_EXTERN
 TeplBuffer *		tepl_buffer_new				(void);
 
+_TEPL_EXTERN
 TeplFile *		tepl_buffer_get_file			(TeplBuffer *buffer);
 
+_TEPL_EXTERN
 TeplMetadata *		tepl_buffer_get_metadata		(TeplBuffer *buffer);
 
+_TEPL_EXTERN
 void			tepl_buffer_load_metadata_from_metadata_manager
 								(TeplBuffer *buffer);
 
+_TEPL_EXTERN
 void			tepl_buffer_save_metadata_into_metadata_manager
 								(TeplBuffer *buffer);
 
+_TEPL_EXTERN
 gboolean		tepl_buffer_is_untouched		(TeplBuffer *buffer);
 
+_TEPL_EXTERN
 gchar *			tepl_buffer_get_short_title		(TeplBuffer *buffer);
 
+_TEPL_EXTERN
 gchar *			tepl_buffer_get_full_title		(TeplBuffer *buffer);
 
+_TEPL_EXTERN
+void			tepl_buffer_provide_style_scheme_id_gsetting
+								(TeplBuffer  *buffer,
+								 GSettings   *settings,
+								 const gchar *setting_key,
+								 gboolean     bind_to_property);
+
+_TEPL_EXTERN
 gchar *			tepl_buffer_get_style_scheme_id		(TeplBuffer *buffer);
 
+_TEPL_EXTERN
 void			tepl_buffer_set_style_scheme_id		(TeplBuffer  *buffer,
 								 const gchar *style_scheme_id);
 
+_TEPL_EXTERN
 TeplSelectionType	tepl_buffer_get_selection_type		(TeplBuffer *buffer);
 
 G_GNUC_INTERNAL
