@@ -1,20 +1,5 @@
-/*
- * This file is part of Tepl, a text editor library.
- *
- * Copyright 2017 - Sébastien Wilmet <swilmet@gnome.org>
- *
- * Tepl is free software; you can redistribute it and/or modify it under
- * the terms of the GNU Lesser General Public License as published by the
- * Free Software Foundation; either version 2.1 of the License, or (at your
- * option) any later version.
- *
- * Tepl is distributed in the hope that it will be useful, but WITHOUT ANY
- * WARRANTY; without even the implied warranty of MERCHANTABILITY or
- * FITNESS FOR A PARTICULAR PURPOSE.  See the GNU Lesser General Public
- * License for more details.
- *
- * You should have received a copy of the GNU Lesser General Public License
- * along with this library; if not, see <http://www.gnu.org/licenses/>.
+/* SPDX-FileCopyrightText: 2017 - Sébastien Wilmet <swilmet@gnome.org>
+ * SPDX-License-Identifier: LGPL-3.0-or-later
  */
 
 #ifndef TEPL_NOTEBOOK_H
@@ -25,6 +10,7 @@
 #endif
 
 #include <gtk/gtk.h>
+#include <tepl/tepl-macros.h>
 
 G_BEGIN_DECLS
 
@@ -53,8 +39,10 @@ struct _TeplNotebookClass
 	gpointer padding[12];
 };
 
+_TEPL_EXTERN
 GType		tepl_notebook_get_type	(void);
 
+_TEPL_EXTERN
 GtkWidget *	tepl_notebook_new	(void);
 
 G_END_DECLS
