@@ -3,7 +3,7 @@
  * SPDX-FileCopyrightText: 2000, 2002 - Chema Celorio, Paolo Maggi
  * SPDX-FileCopyrightText: 2003-2005 - Paolo Maggi
  *
- * SPDX-FileCopyrightText: 2016-2020 - Sébastien Wilmet <swilmet@gnome.org>
+ * SPDX-FileCopyrightText: 2016-2022 - Sébastien Wilmet <swilmet@gnome.org>
  * SPDX-License-Identifier: LGPL-3.0-or-later
  */
 
@@ -228,6 +228,15 @@ out:
 	return dest;
 }
 
+/* Useful for showing additional GtkLabels in a GtkStatusbar.
+ * It uses spaces to have padding proportional to the font size.
+ */
+gchar *
+_tepl_utils_statusbar_add_padding_to_text (const gchar *text)
+{
+	return g_strdup_printf ("  %s  ", text);
+}
+
 static gint
 get_extension_position (const gchar *filename)
 {
@@ -1148,24 +1157,6 @@ tepl_utils_override_font_string (GtkWidget   *widget,
 	}
 }
 
-/**
- * tepl_utils_override_font:
- * @widget: a #GtkWidget.
- * @font_str: (nullable): a string representation of a #PangoFontDescription, or
- *   %NULL to undo the effect of previous calls to this function on @widget.
- *
- * The old name for tepl_utils_override_font_string().
- *
- * Since: 6.0
- * Deprecated: 6.2
- */
-void
-tepl_utils_override_font (GtkWidget   *widget,
-			  const gchar *font_str)
-{
-	tepl_utils_override_font_string (widget, font_str);
-}
-
 /**
  * tepl_utils_get_titled_component:
  * @title: the title.
@@ -1280,3 +1271,76 @@ tepl_utils_binding_transform_func_smart_bool (GBinding     *binding,
 
 	return FALSE;
 }
+
+/**
+ * tepl_utils_can_use_gsettings_schema:
+ * @schema_id: a #GSettings schema ID.
+ *
+ * Checks that a #GSettings schema exists.
+ *
+ * Especially useful for external #GSettings (provided by another application
+ * for instance).
+ *
+ * Returns: %TRUE if a #GSettings instance can be created with @schema_id.
+ *   %FALSE otherwise (in that case the program would crash).
+ * Since: 6.2
+ */
+gboolean
+tepl_utils_can_use_gsettings_schema (const gchar *schema_id)
+{
+	GSettingsSchemaSource *source;
+	GSettingsSchema *schema;
+
+	g_return_val_if_fail (schema_id != NULL, FALSE);
+
+	source = g_settings_schema_source_get_default ();
+	if (source == NULL)
+	{
+		return FALSE;
+	}
+
+	schema = g_settings_schema_source_lookup (source, schema_id, TRUE);
+	if (schema == NULL)
+	{
+		return FALSE;
+	}
+
+	g_settings_schema_unref (schema);
+	return TRUE;
+}
+
+/**
+ * tepl_utils_can_use_gsettings_key:
+ * @settings: a #GSettings object.
+ * @key: the key to introspect.
+ *
+ * Especially useful for external #GSettings (provided by another application
+ * for instance).
+ *
+ * See also: tepl_utils_can_use_gsettings_schema() which is typically used
+ * before this function.
+ *
+ * Returns: whether the #GSettings key exists.
+ * Since: 6.2
+ */
+gboolean
+tepl_utils_can_use_gsettings_key (GSettings   *settings,
+				  const gchar *key)
+{
+	GSettingsSchema *schema = NULL;
+	gboolean can_use;
+
+	g_return_val_if_fail (G_IS_SETTINGS (settings), FALSE);
+	g_return_val_if_fail (key != NULL, FALSE);
+
+	g_object_get (settings,
+		      "settings-schema", &schema,
+		      NULL);
+
+	g_return_val_if_fail (schema != NULL, FALSE);
+
+	can_use = g_settings_schema_has_key (schema, key);
+
+	g_settings_schema_unref (schema);
+	return can_use;
+}
